body {
	font-family: "Microsoft YaHei";
	font-weight: bold;
	font-size: 20px;
	line-height: 35px;
}

.text {
	margin-top: 5px;
	word-break: break-all;
	white-space: pre-wrap;

}

.main-box {
	padding: 5px;
}
